@@ -13,7 +13,7 @@ class globalValues:
         コンストラクタ
         """
 
-        self.config = None
+        self.config:cmnConfig = None
         """ 共通設定 """
 
         self.platForm = self.platFormStruct()
