@@ -611,7 +611,7 @@ class recset(Generic[T]):
 
         """
         内部結合
- 
+
         Parameters
         ----------
         j : saJoin
@@ -785,7 +785,7 @@ class recset(Generic[T]):
         # 戻り値を返す
         return q
     
-    def filter(self, w, s = None):
+    def filter(self, w, s = None, searchOption = findOption.cacheAndDataBase):
         
         """
         レコードセットをフィルタする
@@ -797,32 +797,56 @@ class recset(Generic[T]):
             where条件
         s : Any | asOrderBy
             ソート順
+        searchOption : findOption
+            検索オプション
         """
         
-        # 行情報初期化
-        self.__initRows()
-        
-        # フィールドクラス
-        self.__fields = fields(self.__rows, self.__dfrows)
+        if searchOption == self.findOption.cacheAndDataBase:
+            
+            # 行情報初期化
+            self.__initRows()
+            
+            # フィールドクラス
+            self.__fields = fields(self.__rows, self.__dfrows)
 
-        # セッションチェック
-        self.__checkSessionOpen(False, False)
+            # セッションチェック
+            self.__checkSessionOpen(False, False)
+
+            # クエリ実行
+            rowIndex = 0
+            q = self.filterExpr(w, s).all()
+            for row in q:
+                # 行状態をnoChangedに変更
+                row.__rowState = self.rowState.noChanged
+                # rowsにクエリ結果を追加
+                self.__rows.append(row)
+                # DataFrame - add
+                self.__addRecrowDataFrame(row, rowIndex)
+                rowIndex += 1
+            
+            # セッションチェック
+            self.__checkSessionClose()
+            
+        elif searchOption == self.findOption.cacheOnly:
+            
+            # dfrowsをフィルタする
+            dfw = self.convertDataFrameExpr(self.__dfrows, w)
+            self.__dfrows:pd.DataFrame = self.__dfrows[dfw]
+            
+            # rows初期化
+            self.__rows = []
+
+            # フィールドクラス
+            self.__fields = fields(self.__rows, self.__dfrows)
+            
+            # dfrowsループ
+            for index, item in self.__dfrows.iterrows():
+                row = self.modelType()
+                row.__rowState = self.rowState.noChanged
+                for col in self.__columns:
+                    setattr(row, col[0], item[col[0]])
+                self.__rows.append(row)
 
-        # クエリ実行
-        rowIndex = 0
-        q = self.filterExpr(w, s).all()
-        for row in q:
-            # 行状態をnoChangedに変更
-            row.__rowState = self.rowState.noChanged
-            # rowsにクエリ結果を追加
-            self.__rows.append(row)
-            # DataFrame - add
-            self.__addRecrowDataFrame(row, rowIndex)
-            rowIndex += 1
-        
-        # セッションチェック
-        self.__checkSessionClose()
-        
         # カレント行インデックス初期化
         self.__currentRowIndex = -1
 
